%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% exact.m
% Exact ray tracing using YNU method.
% Inputs:
%      y0 = initial height
%      u0 = initial angle
%       R = radii vector
%       t = thickness vector
%       n = refractive indices vector
% Outputs:
%       z = z positions vector
%       y = ray height vector
%       u = ray angle vector in rad
% Last modied: 12 Dec 2019
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
function [Z,Y,U] = exact(z0,y0, u0, R, t, n)
 % Number of surfaces
 N = length(t);
 % Initial values (height and angle)
 Z(1) = z0;
 Y(1) = y0;
 U(1) = u0;
 b=0;
 %exact ray tracing
 for k=1:N
[Z(k+1),Y(k+1)]= intercept(Z(k),Y(k),U(k),R(k+1),sum(t(1:k)),b);
 q  = asin(Y(k+1)/R(k+1));%q is a center angle
 Ip = asin((n(k)/n(k+1))*sin(U(k)+q));
 U(k+1) = Ip-q;
end

end
