%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% paraxial.m
% Paraxial ray tracing using ynu method.
% Inputs:
%      y0 = initial height
%      u0 = initial angle
%       R = radii vector
%       t = thickness vector
%       n = refractive indices vector
% Outputs:
%       z = t, (z positions vector)
%       y = ray height vector
%       u = ray angle vector in rad
% Last modied: 12 Dec 2019
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 function [z,y,u] = paraxial(z,y,u, R, t, n,ASi)
 
% Number of surfaces
   N = length(t);
   p = zeros(1,N+1);
   
   for k = 1:N
      p(k+1) = (n(k+1)-n(k))/R(k+1);
   end
 
  if nargin == 7
       i=ASi;
      z(i)=z(ASi);
  else
       i=1;
       z = zeros(1,length(y)); 
  end
 
 for k = i:N
     z(k+1) = z(k) + t(k);
     y(k+1) = y(k) + u(k)*t(k);
     u(k+1) = (n(k)*u(k)-p(k+1)*y(k+1))/n(k+1);
 end
 
 end

 



